#
# spec file for package cmis-client
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 0_5-5
%define incname 0.5
%define _name  libcmis
Name:           cmis-client
Version:        0.5.1
Release:        6.1
Summary:        Sample CMIS client
License:        MPL-1.1 or GPL-2.0+ or LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://github.com/tdf/libcmis
Source0:        https://github.com/tdf/%{_name}/releases/download/v%{version}/%{_name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: declare automake foreign
Patch0:         declare-automake-foreign.patch
BuildRequires:  boost-devel >= 1.36
BuildRequires:  docbook2X
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libcppunit-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       %{_name}-%{soname} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Sample client to access CMIS-enabled repositories using libcmis.

%package -n %{_name}-%{soname}
Summary:        Library for accessing CMIS-enabled servers
Group:          System/Libraries

%description -n %{_name}-%{soname}
LibCMIS is a C++ client library for the CMIS (Content Management
Interoperability Services) interface. This allows C++ applications to
connect to any CMIS-enabled repositories.

%package -n %{_name}-devel
Summary:        Libcmis development files
Group:          Development/Libraries/C and C++
Requires:       %{_name}-%{soname} = %{version}

%description -n %{_name}-devel
Development files for libcmis. LibCMIS is a C++ client library for the CMIS interface.
This allows C++ applications to connect to any CMIS-enabled repositories.

%package -n %{_name}-c-%{soname}
Summary:        C Wrapper for libcmis, a library for accessing CMIS-enabled servers
Group:          System/Libraries

%description -n %{_name}-c-%{soname}
libcmis-c is a C client library for the CMIS interface. This allows C applications to connect to any CMIS-enabled repositories.
It is only a wrapper for its C++ sister libcmis.

%package -n %{_name}-c-devel
Summary:        Libcmis-c development files
Group:          Development/Libraries/C and C++
Requires:       %{_name}-c-%{soname} = %{version}

%description -n %{_name}-c-devel
Development files for libcmis-c. Libcmis-c is a C client library for the CMIS interface.
This allows C applications to connect to any CMIS-enabled repositories. It is only a wrapper for its C++ sister libcmis.

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1

%build
autoreconf -fvi
export CFLAGS="%{optflags} -D_GNU_SOURCE $(getconf LFS_CFLAGS)"
export CXXFLAGS="%{optflags} $(getconf LFS_CFLAGS)"
%configure \
    --disable-silent-rules \
    --disable-long-tests \
    --disable-static \
    --disable-werror
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# bypass bug 955832
%ifarch ppc64le
make -k check %{?_smp_mflags} || echo "ignore check error"
%else
make check %{?_smp_mflags}
%endif

%post -n %{_name}-%{soname} -p /sbin/ldconfig
%post -n %{_name}-c-%{soname} -p /sbin/ldconfig
%postun -n %{_name}-%{soname} -p /sbin/ldconfig
%postun -n %{_name}-c-%{soname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_bindir}/cmis-client
%{_mandir}/man1/cmis-client.1.*

%files -n %{_name}-%{soname}
%defattr(-, root, root)
%doc AUTHORS COPYING.LGPL COPYING.MPL COPYING.GPL NEWS
%{_libdir}/%{_name}-%{incname}.so.*

%files -n %{_name}-devel
%defattr(-,root,root)
%{_includedir}/%{_name}-%{incname}
%{_libdir}/pkgconfig/%{_name}-%{incname}.pc
%{_libdir}/%{_name}-%{incname}.so

%files -n %{_name}-c-%{soname}
%defattr(-, root, root)
%doc AUTHORS COPYING.LGPL COPYING.MPL COPYING.GPL NEWS
%{_libdir}/%{_name}-c-%{incname}.so.*

%files -n %{_name}-c-devel
%defattr(-,root,root)
%{_includedir}/%{_name}-c-%{incname}
%{_libdir}/pkgconfig/%{_name}-c-%{incname}.pc
%{_libdir}/%{_name}-c-%{incname}.so

%changelog
* Sun May  8 2016 tchvatal@suse.com
- Simplify autoreconf call and add patch to mark Makefile as foreign:
  * declare-automake-foreign.patch
* Fri Mar  4 2016 tchvatal@suse.com
- Version update to 0.5.1:
  * Few small bugfixes, see NEWS file for details
- Remove upstreamed patches
  * 0001-fix-boost-configuration-with-gcc-5.patch
  * 0002-avoid-use-after-delete.patch
  * 0005-Remove-invalid-comments-from-test-JSON-file.patch
* Fri Nov 20 2015 normand@linux.vnet.ibm.com
- for ppc64le bypass boo#955832: disable stop on make check error
* Tue Nov 17 2015 idonmez@suse.com
- Add 0005-Remove-invalid-comments-from-test-JSON-file.patch to fix
  test-onedrive failure with boost 1.59
  (http://sourceforge.net/p/libcmis/tickets/13/)
* Wed May  6 2015 fstrba@suse.com
- Added patches:
  * 0001-fix-boost-configuration-with-gcc-5.patch
  - Upstream fix for boost detection with gcc5
  * 0002-avoid-use-after-delete.patch
  - Upstream fix for test-ws failure
- Removed patch:
  * fix-boost-with-gcc5.patch
  - Superseded by the two previous patches
* Wed May  6 2015 coolo@suse.com
- fix-boost-with-gcc5.patch: upsream patch to support gcc5
* Wed May  6 2015 coolo@suse.com
- use upstream source url
* Sat Dec 27 2014 p.drouand@gmail.com
- Update to version 0.5.0
  + Completely removed the dependency on InMemory server for unit tests
  + Minimized the number of HTTP requests sent by
    SessionFactory::createSession
  + Added Session::getBaseTypes()
- Remove merged patches;
  + 433fad3-Fix-int-bool-confusion-on-big-endian-architectures.patch
  + 0001-Remove-C-11-only-std-to_string.patch
- Bump soname to 0_5-5
- Bump incname to 0.5
* Wed Jul  2 2014 fstrba@suse.com
- 0001-Remove-C-11-only-std-to_string.patch
  Fix some C++11-isms.
* Tue Mar  4 2014 cbosdonnat@suse.com
- 433fad3-Fix-int-bool-confusion-on-big-endian-architectures.patch
  Fix problem with big endian architectures. bnc#866716
* Mon Dec 30 2013 tchvatal@suse.com
- Whitespace cleanup here&there.
* Tue Nov 12 2013 jengelh@inai.de
- Set RPM groups of shlib packages to what we normally use
- Make a note in the description about what "CMIS" is
- Require boost-1.42 (first one to have the mandatory uuid.hpp)
* Wed Aug  7 2013 cbosdonnat@suse.com
- Update to version 0.4.1
  + 0.4.0
    + Support for Google Drive protocol as a binding
    + Support for Alfresco in the cloud
    + Added OAuth2 authentication support
    + Added API to configure HTTP proxy
    + Handle invalid SSL certificate problems
    + Added API for renditions
    + Moved the CMIS Atom binding unit tests to use libcurl mockup
    + Added repository capabilities support (still missing
    capabilityCreatablePropertyTypes and capabilityNewTypeSettableAttributes)
  + 0.4.1
    + Don't install the libcmis-mockup library: only for testing purpose
* Mon Jun 10 2013 crrodriguez@opensuse.org
- Build with large file support in 32 bit archs, no good
  will come mixing LFS-aware executables and non-LFS libraries.
* Thu Jan 31 2013 tchvatal@suse.com
- Version bup to 0.3.1
  * 0.3.1
  * Added support for proxy configuration
  * Fixed man page generation
  * Misc code cleanup / fixes
* Fri Jan 25 2013 tchvatal@suse.com
- Fix libcmis-c-devel dependency over itself.
* Thu Sep 13 2012 cbosdonnat@suse.com
- Update to version 0.3.0
  + 0.2.2
    + Fixed soname for the library
    + Allow building against libcurl 7.13.1
  + 0.2.3
    + Fixed SharePoint support
    + Conditional build of man page
  + 0.3.0
    + Added Document::checkOut(), Document::cancelCheckout() and Document::checkIn()
    + Added Object::move( ) -- Grau Data
    + Fixes for xcmis and cloudoku.com -- Grau Data
    + Added Document::getAllVersions( )
    + WebService binding implementation
    + Session factory automatically detects which binding to use
    + C wrapper API
    + Unit tests are now split between quick ones and the ones needing a CMIS server
* Mon Jun  4 2012 cbosdonnat@suse.com
- Update to version 0.2.1
  + 0.2.0
    + Handle all the authentication methods that can be handled by
    libcurl like Basic, NTLM...
    + Decode base64 encoded content sent by SharePoint
    + Set the content of a document
    + Query nodes by path
    + Get the allowable actions for a node
    + Object properties can be updated
    + Query object types
    + Creation of folders and documents
    + Deletion of folders and documents
  + 0.2.1
    + Fixed documentation distribution
* Tue May 29 2012 cbosdonnat@suse.com
- Fixed licenses
* Tue Oct  4 2011 cbosdonnat@suse.com
- Created initial package with libcmis 0.1.0
